// #name = pingHud
// #version = 1.0
// #date = 25th April 2001
// #author = Crunchy
// #email = crunchy@barrysworld.com
// #web = http://www.tribalwar.com/crunchy/
// #description = Small, cute, ping HUD
// #status = final

//
// --- Preferences ---
//

// Colour of label text in terms of "R G B"
$pingHudLabelColour = "0 255 0";

// Colour of main text in terms of "R G B"
$pingHudTextColour = "255 255 255";

//
// --- Main Code ---
//

// START package pingHud
package pingHud {


function pingHudUpdate()
{
	if ($pingHudSchedule != 0) cancel($pingHudSchedule);
	
	// Update scores which includes ping, no need if TabMenuHud is up however
	if (!$TabMenuHudOn) commandToServer('getScores');
	
	%player = $PlayerList[$pingHudClient];
	pingHud.text.setValue((%player.ping > 999) ? 999 : %player.ping);
	
	$pingHudSchedule = schedule(4000, 0, pingHudupdate);
}

function pingHudSetup()
{
	new GuiControlProfile ("pingHudLabelProfile")
	{
		fontType = "Univers Condensed";
		fontSize = 16;
		fontColor = $pingHudLabelColour;
		justify = "center";
	};	
	new GuiControlProfile ("pingHudTextProfile")
	{
		fontType = "Univers Condensed";
		fontSize = 16;
		fontColor = $pingHudTextColour;
		justify = "center";
	};
	
	addMessageCallback('MsgClientJoin', pingHudClientJoin);
}

function pingHudCreate()
{
	pingHudDestroy();
	
	%x = getWord(hudClusterBack.position, 0)-43-8;
	%y = getWord(hudClusterBack.position, 1)+20;
	
	new ShellFieldCtrl(pingHud)
	{
		profile = "GuiChatBackProfile";
		horizSizing = "left";
		vertSizing = "bottom";
		position = %x SPC %y;
		extent = "43 16";
		minExtent = "8 8";
		visible = "1";
		
		new GuiTextCtrl()
		{
			profile = "pingHudLabelProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "3 0";
			extent = "20 16 ";
			visible = "1";
			text = "Ping";
		};
	};

	pingHud.text = new GuiTextCtrl() {
		profile = "pingHudTextProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "22 0";
		extent = "20 16 ";
		visible = "1";
	};

	pingHud.add(pingHud.text);
	playGui.add(pingHud);
}

function pingHudDestroy()
{
	if ($pingHudSchedule != 0) cancel($pingHudSchedule);
	
	if (isObject(pingHud))
	{
		playGui.remove(pingHud);
		pingHud.delete();
	}
}

function pingHudClientJoin(%msgType, %msgString, %clientName, %clientId, %targetId, %isAI, %isAdmin, %isSuperAdmin, %isSmurf, %guid)
{
	if ($pingHudOnline)
	{
		if ($pingHudWonId == %guid) $pingHudClient = %clientId;
	}
	else
	{
		if ($pingHudName == %clientName) $pingHudClient = %clientId;
	}
}

//
// --- Overrides ---
//

function PlayOffline()
{
	parent::PlayOffline();

	$pingHudOnline = false;
}

function OnlineLogIn()
{
	parent::OnlineLogIn();

	$pingHudOnline = true;
	$pingHudWonId = getField(WONGetAuthInfo(), 3);
}

function clientCmdTogglePlayHuds(%val)
{
	parent::clientCmdTogglePlayHuds(%val);

	pingHud.setVisible(%val);
}

function DispatchLaunchMode()
{
	pingHudSetup();

	parent::DispatchLaunchMode();
}

function LoadingGui::onWake(%this)
{
	if (!$pingHudOnline)
	{
		$pingHudName = getField($pref::Player[$pref::Player::Current], 0);
	}	
	
	if (!$pingHudCreate)
	{
		pingHudCreate();
		pingHudUpdate();
	
		if (isObject(HudMover)) hudmover::addhud(pingHud, "pingHud");

		$pingHudCreate = true;
	}
	
	parent::onWake(%this);
}


}; // END package pingHud
activatePackage(pingHud);
